# Genetica

## About

**Genetica** is the minimalistic genetic algorithm library for optimizing class parameters.

This high-level library allows you to take any class with certain business logic, modify it a little and then give it back to Genetica to optimize.

Right now Genetica is a *minimalistic* library. It lacks some of the fancy aspects of genetic algorithms. Nevertheless, the library was created to optimize some aerospace designs for the author's graduation project.

Now you can enjoy the core idea of genetic optimization without much pain of getting into it:

- Turning class parameters into manipulatable genes
- Population generation (any size)
- Crossbreeding with mutations
- Learning process chart (not real-time)
- Real-time learning feedback
- Getting the best and worst species' parameters